@@ -279,7 +279,8 @@ def mean_absolute_shap_values(columns, shap_values, cats=None):
     return shap_df
 
 
-def get_precision_df(pred_probas, y_true, bin_size=None, quantiles=None, pos_label=1):
+def get_precision_df(pred_probas, y_true, bin_size=None, quantiles=None, 
+                        round=3, pos_label=1):
     """
     returns a pd.DataFrame with the predicted probabilities and
     the observed frequency per bin_size.
@@ -403,7 +404,13 @@ def get_precision_df(pred_probas, y_true, bin_size=None, quantiles=None, pos_lab
             new_row_df = pd.DataFrame(new_row_dict, columns=precision_df.columns)
             precision_df = pd.concat([precision_df, new_row_df])
             last_p_max = preds.max()
-    
+
+    precision_df[['p_avg', 'precision']] = precision_df[['p_avg', 'precision']]\
+                .astype(float).apply(partial(np.round, decimals=round))
+    if n_classes > 1:
+        precision_cols = ['precision_' + str(i) for i in range(n_classes)]
+        precision_df[precision_cols] = precision_df[precision_cols]\
+                .astype(float).apply(partial(np.round, decimals=round))
     return precision_df
 
 
